'''A setuptools based setup module.
See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
'''

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='ligament-jinja',
    version='0.0.4.dev',
    description='A jinja build task for ligament',
    url='http://github.com/Adjective-Object/ligament_jinja',
    author='Adjective-Object',
    author_email='mhuan13@gmail.com',
    license='Apache 2',

    classifiers=[
        'Development Status :: 3 - Alpha',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 2.7'],

    keywords='ligament grunt build automation jinja',
    install_requires=['ligament>=0.0.3.dev', 'Jinja2>=2.7.3'],

    packages=["ligament_jinja"]
)



""" Basic Jinja2 templating for the `ligament` task automator"""
import os
import jinja2
from ligament.buildtarget import BuildTarget

from ligament.helpers import mkdir_recursive

class SimpleJinja(BuildTarget):

    def __init__(self, template_file="", filters={}, **kwargs):
        BuildTarget.__init__(self, **kwargs)

        self.template_file  = template_file
        self.jinja_env = jinja2.Environment(
            loader=jinja2.FileSystemLoader(
                os.path.dirname(self.template_file)))

        self.jinja_env.filters = filters

        self.input_basename = os.path.basename(self.template_file)

        self.file_watch_targets = [os.path.abspath(self.template_file)]

    def build(self, output_file=None, **kwargs):

        if output_file is not None:
            directory = os.path.dirname(output_file)
            if directory != "" and not os.path.exists(directory):
                mkdir_recursive(os.path.dirname(output_file))

        template = self.jinja_env.get_template(self.input_basename)
        html = template.render(
            **kwargs
        )

        if output_file is not None:
            with open(output_file, 'w') as template_output:
                template_output.write(html)

        return html
